==> peek-core-user-2.3.2.tar.gz: peek-core-user-2.3.2/peek_core_user/_private/admin-app/edit-ldap-setting-table/edit.component.ts <==
import {Component, OnInit} from "@angular/core";
import {
    extend,
    VortexService,
    ComponentLifecycleEventEmitter,
    TupleLoader
} from "@synerty/vortexjs";
import {userFilt} from "@peek/peek_core_user/_private";
import {LdapSettingTuple} from "../tuples/LdapSettingTuple";
import {Ng2BalloonMsgService} from "@synerty/ng2-balloon-msg";


@Component({
    selector: 'pl-user-edit-ldap-setting',
    templateUrl: './edit.component.html'
})
export class EditLdapSettingComponent extends ComponentLifecycleEventEmitter {
    // This must match the dict defined in the admin_backend handler
    private readonly filt = {
        "key": "admin.Edit.LdapSetting"
    };

    items: LdapSettingTuple[] = [];
    itemsToDelete: LdapSettingTuple[] = [];

    loader: TupleLoader;

    constructor( private balloonMsg:Ng2BalloonMsgService,
        vortexService: VortexService) {
        super();

        this.loader = vortexService.createTupleLoader(
            this, extend({}, this.filt, userFilt)
        );

        this.loader.observable
            .subscribe((tuples:LdapSettingTuple[]) => {
                this.items = tuples;
                this.itemsToDelete = [];
            });
    }

    addRow() {
        let t = new LdapSettingTuple();
        // Add any values needed for this list here, EG, for a lookup list you might add:
        // t.lookupName = this.lookupName;
        this.items.push(t);
    }

    removeRow(item) {
        if (item.id != null)
            this.itemsToDelete.push(item);

        let index: number = this.items.indexOf(item);
        if (index !== -1) {
            this.items.splice(index, 1);
        }
    }

    save() {
        let itemsToDelete = this.itemsToDelete;

        this.loader.save(this.items)
            .then(() => {
                if (itemsToDelete.length != 0) {
                    return this.loader.del(itemsToDelete);
                }
            })
            .then(() => this.balloonMsg.showSuccess("Save Successful"))
            .catch(e => this.balloonMsg.showError(e));
    }

}

==> peek-core-user-2.5.6.tar.gz: peek-core-user-2.5.6/peek_core_user/_private/admin-app/edit-ldap-setting-table/edit.component.ts <==
import {Component, OnInit} from "@angular/core";
import {
    extend,
    VortexService,
    ComponentLifecycleEventEmitter,
    TupleLoader
} from "@synerty/vortexjs";
import {userFilt} from "@peek/peek_core_user/_private";
import {LdapSettingTuple} from "../tuples/LdapSettingTuple";
import { BalloonMsgService } from "@synerty/peek-plugin-base-js"


@Component({
    selector: 'pl-user-edit-ldap-setting',
    templateUrl: './edit.component.html'
})
export class EditLdapSettingComponent extends ComponentLifecycleEventEmitter {
    // This must match the dict defined in the admin_backend handler
    private readonly filt = {
        "key": "admin.Edit.LdapSetting"
    };

    items: LdapSettingTuple[] = [];
    itemsToDelete: LdapSettingTuple[] = [];

    loader: TupleLoader;

    constructor( private balloonMsg:BalloonMsgService,
        vortexService: VortexService) {
        super();

        this.loader = vortexService.createTupleLoader(
            this, extend({}, this.filt, userFilt)
        );

        this.loader.observable
            .subscribe((tuples:LdapSettingTuple[]) => {
                this.items = tuples;
                this.itemsToDelete = [];
            });
    }

    addRow() {
        let t = new LdapSettingTuple();
        // Add any values needed for this list here, EG, for a lookup list you might add:
        // t.lookupName = this.lookupName;
        this.items.push(t);
    }

    removeRow(item) {
        if (item.id != null)
            this.itemsToDelete.push(item);

        let index: number = this.items.indexOf(item);
        if (index !== -1) {
            this.items.splice(index, 1);
        }
    }

    save() {
        let itemsToDelete = this.itemsToDelete;

        this.loader.save(this.items)
            .then(() => {
                if (itemsToDelete.length != 0) {
                    return this.loader.del(itemsToDelete);
                }
            })
            .then(() => this.balloonMsg.showSuccess("Save Successful"))
            .catch(e => this.balloonMsg.showError(e));
    }

}
